data_methyl: data_methyl

data_methylR Documentation

data_methyl

Description

Extract from the methylation data set of Ribaud et al. from site 119521761 to 119527907

Usage

data(data_methyl)

Format

A list with two elements: Y the matrix with the methylation level for each samples and sites, sites the genomic position of sites, X the covariate whith the cell type

Details

  • ID.source are the ID of source hosts

  • ID.recep are the ID of receiver hosts

  • y are the vector of transmission probabilities source -> receiver

  • other columns are the factors

Author(s)

Melina Ribaud

References

Melina Ribaud, Aurélie Labbe and Karim Oualkacha. Imputation in genetic methylation studies: A linear model of coregionalization (LMC) with informative covariates. 2022. hal-00000000


melinaR/olsgasp documentation built on March 11, 2023, 12:10 a.m.