| data_methyl | R Documentation |
Extract from the methylation data set of Ribaud et al. from site 119521761 to 119527907
data(data_methyl)
A list with two elements: Y the matrix with the methylation level for each samples and sites, sites the genomic position of sites, X the covariate whith the cell type
ID.source are the ID of source hosts
ID.recep are the ID of receiver hosts
y are the vector of transmission probabilities source -> receiver
other columns are the factors
Melina Ribaud
Melina Ribaud, Aurélie Labbe and Karim Oualkacha. Imputation in genetic methylation studies: A linear model of coregionalization (LMC) with informative covariates. 2022. hal-00000000
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.